@@ -15,6 +15,59 @@
 #include "mappings.h"
 #include "settings.h"
 
+void do_properties_recache(DeviceInfo info, MYSQL *mysql)
+{
+	string query = string("SELECT id, test_type, test_id, test_params, name FROM dev_props WHERE dev_type_id = " + inttostr(info.device_type));
+
+	MYSQL_RES *mysql_res = db_query(mysql, &info, query);
+	MYSQL_ROW mysql_row;
+
+	for (uint i = 0; i < mysql_num_rows(mysql_res); i++)
+	{
+		mysql_row = mysql_fetch_row(mysql_res);
+
+		string value;
+		info.property_id	= strtoint(mysql_row[0]);
+		info.test_type		= strtoint(mysql_row[1]);
+		info.test_id		= strtoint(mysql_row[2]);
+		info.test_params	= mysql_row[3];
+		info.parameters.push_front(ValuePair("parameters", info.test_params));
+
+		switch (info.test_type)
+		{
+			case  1:	value = process_script_monitor(info, mysql);
+						value = strstripnl(value);
+						break;
+	
+			case  2:	value = process_snmp_monitor(info, mysql);
+						value = remove_surrounding_quotes(value);	
+						break;
+	
+			case  3:	value = process_sql_monitor(info, mysql);
+						break;
+	
+			case  4:	value = process_internal_monitor(info, mysql);
+						break;
+	
+			default:	debuglogger(DEBUG_PROPERTY, LEVEL_WARNING, &info, "Unknown test type (" + inttostr(info.test_type) + ").");
+						value = "U";
+		} // end switch
+
+		if (value != "U")
+		{
+			debuglogger(DEBUG_PROPERTY, LEVEL_INFO, &info, string("Device Property '") + mysql_row[4] + "' set to {'" + value + "'}");
+			db_update(mysql, &info, "REPLACE INTO dev_prop_vals SET dev_id=" + inttostr(info.device_id) + ", prop_id=" + mysql_row[0] + ", value='" + db_escape(value) + "'");
+		}
+		else
+		{
+			debuglogger(DEBUG_PROPERTY, LEVEL_INFO, &info, "Device Property test failed, skipping update.");
+		}
+	}
+	
+	mysql_free_result(mysql_res);
+
+} // end do_properties_recache
+
 uint process_sub_device(DeviceInfo info, MYSQL *mysql)
 {
 	MYSQL_RES	*mysql_res;
@@ -198,19 +251,21 @@ void process_device(int dev_id)
 	debuglogger(DEBUG_DEVICE, LEVEL_INFO, &info, "MySQL connection established.");
 	info.mysql = (void *) &mysql;
 
-	string query = 	string("SELECT ") 		+
-			string("name, ")				+ // 0
-			string("ip, ")					+ // 1
-			string("snmp_version, ")		+ // 2
-			string("snmp_read_community, ")	+ // 3
-			string("snmp_recache_method, ")	+ // 4
-			string("snmp_uptime, ")			+ // 5
-			string("snmp_ifnumber, ")		+ // 6
-			string("snmp_port, ")			+ // 7
-			string("snmp_timeout, ")		+ // 8
-			string("snmp_retries, ")		+ // 9
-			string("no_snmp_uptime_check ")	+ // 10
-			string("FROM devices ")			+
+	string query = 	string("SELECT ") 			+
+			string("name, ")					+ // 0
+			string("ip, ")						+ // 1
+			string("snmp_version, ")			+ // 2
+			string("snmp_read_community, ")		+ // 3
+			string("snmp_recache_method, ")		+ // 4
+			string("snmp_uptime, ")				+ // 5
+			string("snmp_ifnumber, ")			+ // 6
+			string("snmp_port, ")				+ // 7
+			string("snmp_timeout, ")			+ // 8
+			string("snmp_retries, ")			+ // 9
+			string("no_snmp_uptime_check, ")	+ // 10
+			string("dev_type, ")				+ // 11
+			string("unknowns_on_snmp_restart ") + // 12
+			string("FROM devices ")				+
 			string("WHERE id=") + inttostr(dev_id);
 
 	mysql_res = db_query(&mysql, &info, query);
@@ -219,6 +274,7 @@ void process_device(int dev_id)
 	info.name					= mysql_row[0];
 	info.ip						= mysql_row[1];
 	info.snmp_version			= strtoint(mysql_row[2]);
+	info.device_type			= strtoint(mysql_row[11]);
 
 	debuglogger(DEBUG_DEVICE, LEVEL_INFO, &info, info.name + " / {" + info.ip + "}");
 
@@ -280,6 +336,13 @@ void process_device(int dev_id)
 						// device came back from the dead
 						info.snmp_recache = 1;
 						debuglogger(DEBUG_DEVICE, LEVEL_NOTICE, &info, "Device has returned from SNMP-death.");
+
+						// write unknowns to counters, if configured to
+						if (strtoint(mysql_row[12]) == 1)
+						{
+							info.counter_unknowns = 1;
+							debuglogger(DEBUG_DEVICE, LEVEL_NOTICE, &info, "Using unknowns for non-gauge values.");
+						}
 					}
 
 					if (info.snmp_uptime < strtoint(mysql_row[5]))
@@ -287,6 +350,14 @@ void process_device(int dev_id)
 						// uptime went backwards
 						info.snmp_recache = 1;
 						debuglogger(DEBUG_SNMP, LEVEL_NOTICE, &info, "SNMP Agent Restart.");
+
+						// write unknowns to counters, if configured to
+						if (strtoint(mysql_row[12]) == 1)
+						{
+							info.counter_unknowns = 1;
+							debuglogger(DEBUG_DEVICE, LEVEL_NOTICE, &info, "Using unknowns for non-gauge values.");
+						}
+
 					}
 				}
 			}
@@ -319,7 +390,7 @@ void process_device(int dev_id)
 
 					cache_mysql_res = db_query(&mysql, &info, string("SELECT count(*) FROM snmp_interface_cache WHERE dev_id = ") + inttostr(info.device_id));
 					cache_mysql_row = mysql_fetch_row(cache_mysql_res);
-					int interface_cache_count = strtoint(cache_mysql_row[0]);
+					unsigned int interface_cache_count = strtoint(cache_mysql_row[0]);
 					mysql_free_result(cache_mysql_res);
 
 					if (info.snmp_ifnumber != interface_cache_count)
@@ -346,6 +417,7 @@ void process_device(int dev_id)
 			debuglogger(DEBUG_SNMP, LEVEL_NOTICE, &info, "Performing SNMP Recache.");
 			do_snmp_interface_recache(&info, &mysql);
 			do_snmp_disk_recache(&info, &mysql);
+			do_properties_recache(info, &mysql);
 		}
 	} // end snmp-enabled
 	else
