@@ -45,7 +45,7 @@ uint process_event(DeviceInfo info, MYSQL *mysql, int trigger_type, int last_sta
 	MYSQL_ROW	mysql_row;
 	uint		status = 0;
 
-	string query = "SELECT value, value_type, condition, logic_condition FROM conditions WHERE event_id=" + inttostr(info.event_id) + " ORDER BY id";
+	string query = "SELECT `value`, `value_type`, `condition`, `logic_condition` FROM `conditions` WHERE `event_id` = '" + inttostr(info.event_id) + "' ORDER BY `id`";
 	mysql_res = db_query(mysql, &info, query);
 
 	for (uint i = 0; i < mysql_num_rows(mysql_res); i++)
@@ -161,6 +161,7 @@ void process_responses(DeviceInfo info, MYSQL *mysql)
 {
 	MYSQL_RES	*mysql_res;
 	MYSQL_ROW	mysql_row;
+	int			notification_res;
 
 	string query = 	string("SELECT	notifications.command, responses.parameters, responses.id ") 	+
 			string("FROM	responses, notifications ")			+
@@ -178,7 +179,7 @@ void process_responses(DeviceInfo info, MYSQL *mysql)
 		if (command[0] != '/')
 			command = get_setting(setPathLibexec) + "/" + command;
 		debuglogger(DEBUG_RESPONSE, LEVEL_INFO, &info, "Running Response: " + command);
-		system(command.c_str());
+		notification_res = system(command.c_str());
 	}
 
 } // end process_responses()
