@@ -35,5 +35,12 @@
 #  include <netinet/in.h>
 #endif
 
+#include "gettext.h"
+#define _(String) gettext(String)
+
+#if HAVE_SYS_WAIT_H
+# include <sys/wait.h>
+#endif
+
 #endif /* NETMRG_COMMON_H */
 
