@@ -22,6 +22,7 @@
 #include "common.h"
 #include <cstdio>
 #include <cstdlib>
+#include <cstring>
 #include <unistd.h>
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -106,13 +107,14 @@ void run_netmrg()
 	
 	pid_t mypid = getpid();
 	FILE *lockfile;
+	int lockfile_res;
 	
 	// check for existing lockfile
 	if (file_exists(get_setting(setPathLockFile)))
 	{
 		lockfile = fopen(get_setting(setPathLockFile).c_str(), "r");
 		pid_t otherpid;
-		fscanf(lockfile, "%d", &otherpid);
+		lockfile_res = fscanf(lockfile, "%d", &otherpid);
 		fclose(lockfile);
 		
 		// if we could have sent the signal, or if the problem wasn't finding the PID, die.
@@ -282,6 +284,7 @@ void run_netmrg()
 			{
 				timespec tosleep, unslept;
 				tosleep.tv_sec = start_time + get_setting_int(setPollInterval) - time(NULL);
+				tosleep.tv_nsec = 0;
 				while (nanosleep(&tosleep, &unslept))
 				{
 					if ((errno == EINTR) && (netmrg_terminated))
@@ -321,6 +324,7 @@ void show_usage()
 	printf("\nMode of Operation:\n");
 	printf("-i <devid>  Recache the interfaces of device <devid>\n");
 	printf("-d <devid>  Recache the disks of device <devid>\n");
+	printf("-P <devid>  Recache the properties of device <devid>\n");
 	printf("-K <file>   Parse config file <file>, or default if omitted (for syntax checking)\n");
 	printf("If no mode is specified, the default is to gather data for all enabled devices.\n");
 
@@ -359,7 +363,7 @@ void external_snmp_recache(int device_id, int type)
 	info.device_id = device_id;
 
 	mysql_res = db_query(&mysql, &info, string("SELECT ip, snmp_read_community, snmp_version, snmp_port, ") +
-		"snmp_timeout, snmp_retries FROM devices WHERE id=" + inttostr(device_id));
+		"snmp_timeout, snmp_retries, dev_type FROM devices WHERE id=" + inttostr(device_id));
 	mysql_row = mysql_fetch_row(mysql_res);
 
 	if (mysql_row == NULL)
@@ -381,6 +385,9 @@ void external_snmp_recache(int device_id, int type)
 	info.snmp_port				= strtoint(mysql_row[3]);
 	info.snmp_timeout			= strtoint(mysql_row[4]);
 	info.snmp_retries			= strtoint(mysql_row[5]);
+	info.device_type			= strtoint(mysql_row[6]);
+	info.parameters.push_front(ValuePair("ip", info.ip));
+	info.parameters.push_front(ValuePair("snmp_read_community", info.snmp_read_community));
 
 	mysql_free_result(mysql_res);
 
@@ -390,6 +397,7 @@ void external_snmp_recache(int device_id, int type)
 	{
 		case 1: do_snmp_interface_recache(&info, &mysql);	break;
 		case 2: do_snmp_disk_recache(&info, &mysql); 		break;
+		case 3: do_properties_recache(info, &mysql);		break;
 	}
 	snmp_session_cleanup(info);
 	snmp_cleanup();
@@ -400,6 +408,7 @@ void external_snmp_recache(int device_id, int type)
 void daemonize()
 {
 	pid_t pid;
+	int chdir_res;
 
 	pid = fork();
 	if (pid < 0)
@@ -418,7 +427,7 @@ void daemonize()
 	{
 		// we're the child, keep going
 		setsid();
-		chdir("/");
+		chdir_res = chdir("/");
 		umask(0);
 		return;
 	}
@@ -437,7 +446,7 @@ int main(int argc, char **argv)
 		set_log_method(LOG_METHOD_VT100);
 	}
 
-	while ((option_char = getopt(argc, argv, "hvXSqasmbM:i:d:c:l:H:D:u:p::t:C:K::")) != EOF)
+	while ((option_char = getopt(argc, argv, "hvXSqasmbM:i:d:P:c:l:H:D:u:p::t:C:K::")) != EOF)
 		switch (option_char)
 		{
 			case 'h': 	show_usage();
@@ -465,6 +474,9 @@ int main(int argc, char **argv)
 			case 'd': 	external_snmp_recache(strtoint(optarg), 2);
 						exit(0);
 						break;
+			case 'P':	external_snmp_recache(strtoint(optarg), 3);
+						exit(0);
+						break;
 			case 'c':	set_debug_components(strtoint(optarg));
 						break;
 			case 'l':	set_debug_level(strtoint(optarg));
