@@ -8,6 +8,7 @@
 ********************************************/
 
 #include <string>
+#include <cstring>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <syslog.h>
@@ -41,6 +42,16 @@ int file_exists(string filename)
 	return !(stat(filename.c_str(), &file_stat));
 }
 
+// remove_surrounding_quotes - removes leading and trailing quotes, if present
+string remove_surrounding_quotes(string input)
+{
+	if (input[0] == '"')
+		input.erase(0,1);
+	if (input[input.length() - 1] == '"')
+		input.erase(input.length() - 1, 1);
+	return input;
+}
+
 // strstripnl - given a string, return a string without new line at the end
 string strstripnl(string input)
 {
@@ -306,10 +317,12 @@ string remove_braces(const string & message)
 //
 // component	- the sum of the components this message pertains to
 // level		- the sum of the levels this message pertains to
+// file, line,
+// function		- provided by the LEVEL_* macros
 // info			- the DeviceInfo struct, used to display the context of the message
 // message		- the message, sensitive information enclosed in braces will be censored when desired
 //
-void debuglogger(int component, int level, const DeviceInfo * info, const string & message)
+void __debuglogger(int component, int level, const char * file, int line, const char * function, const DeviceInfo * info, const string & message)
 {
 	// only proceed if this message is qualified for display
 	if ((debug_level & level) && (debug_components & component))
@@ -330,6 +343,11 @@ void debuglogger(int component, int level, const DeviceInfo * info, const string
 				tempmsg = tempmsg + string("[Dev: ") + inttopadstr(info->device_id, 4) + string("] ");
 			}
 
+			if (info->property_id != -1)
+			{
+				tempmsg = tempmsg + string("[Pro: ") + inttopadstr(info->property_id, 4) + string("] ");
+			}
+
 			if (info->subdevice_id != -1)
 			{
 				tempmsg = tempmsg + string("[Sub: ") + inttopadstr(info->subdevice_id, 4) + string("] ");
@@ -365,6 +383,18 @@ void debuglogger(int component, int level, const DeviceInfo * info, const string
 			content = remove_braces(message);
 		}
 
+		if ( (debug_components & DEBUG_FILELINE) || (debug_components & DEBUG_FUNCTION) )
+			context = context + "[";
+
+		if (debug_components & DEBUG_FILELINE)
+			context = context + file + "(" + inttostr(line) + ")";
+
+		if (debug_components & DEBUG_FUNCTION)
+			context = context + ":" + function;
+
+		if ( (debug_components & DEBUG_FILELINE) || (debug_components & DEBUG_FUNCTION) )
+			context = context + "] ";
+
 		fullmessage = context + content;
 
 		if (log_method & LOG_METHOD_STDOUT)
