@@ -51,12 +51,20 @@ function esc_colon()
 
 function rrd_slope()
 {
-	// if escaping a colon, return the escape sequence, otherwise an empty string
+	// use slope smoothing if rrdtool > 1.0
 
 	if (!strstr($GLOBALS['netmrg']['rrdtool_version'], "1.0"))
 		return "-E"; else return "";
 }
 
+function rrd_watermark()
+{
+	// add a watermark if rrdtool > 1.0
+
+	if (!strstr($GLOBALS['netmrg']['rrdtool_version'], "1.0"))
+		return " -W 'NetMRG - www.netmrg.net' "; else return "";
+}
+
 function get_graph_command($type, $id, $hist)
 {
 
@@ -225,15 +233,21 @@ function custom_graph_command($id, $timeframe, $templated, $single_ds)
 	}
 
 	// initial definition
-	$command = $GLOBALS['netmrg']['rrdtool'] . " graph - " . rrd_slope() . " -s " . $timeframe['start_time'] . 
+	$command = $GLOBALS['netmrg']['rrdtool'] . " graph - " . rrd_slope() . rrd_watermark() . " -s " . $timeframe['start_time'] . 
 			" -e " . $timeframe['end_time'] . $boundary . " --title " . $graph_row["title"] . " -w " .
 			$graph_row["width"] . " -h " . $graph_row["height"] . $options . "-b " . $graph_row["base"] . " -v " .
 			$graph_row["vert_label"] . " --imgformat PNG $options";
 
+	// setup condition to only display non-AVERAGE items on graphs 
+	$ew = "";
+	if ($timeframe['show_max'] == false)
+	{
+		$ew = "AND cf=1";
+	}
 
 	// *** Padded Length Calculation
 	$padded_length = 5;
-	$ds_results = db_query("SELECT max(length(graph_ds.label)) as maxlen FROM graph_ds WHERE graph_ds.graph_id=$id");
+	$ds_results = db_query("SELECT max(length(graph_ds.label)) as maxlen FROM graph_ds WHERE graph_ds.graph_id=$id $ew");
 	$ds_row = mysql_fetch_array($ds_results);
 	if (!empty($ds_row['maxlen']) && $padded_length < $ds_row['maxlen'])
 	{
@@ -247,7 +261,7 @@ function custom_graph_command($id, $timeframe, $templated, $single_ds)
 	}
 	else
 	{
-		$ds_where = "graph_id=$id ORDER BY position, id";
+		$ds_where = "graph_id=$id $ew ORDER BY position, id";
 	}
 
 	$ds_results = db_query("SELECT * FROM graph_ds WHERE $ds_where");
@@ -382,7 +396,12 @@ function custom_graph_command($id, $timeframe, $templated, $single_ds)
 			$CDEF_M = "zero,UN,0,0,IF";
 		}
 
-		$command .= $ds_row["type"] . ":data" . $ds_count . $ds_row["color"] . rrd_legend_escape(do_align($ds_row["label"], $padded_length, $ds_row["alignment"])) . " ";
+		$suffix = "";
+		if ($ds_row['cf'] == 2)
+		{
+			$suffix = "m";
+		}
+		$command .= $ds_row["type"] . ":data" . $ds_count . $suffix . $ds_row["color"] . rrd_legend_escape(do_align($ds_row["label"], $padded_length, $ds_row["alignment"])) . " ";
 
 		// define the formatting string
 		if (isin($ds_row["stats"], "INTEGER"))
