@@ -148,8 +148,8 @@ function rrd_legend_escape($string)
 
 function get_microtime()
 {
-    list($usec, $sec) = explode(" ", microtime());
-    return ((float)$usec + (float)$sec);
+	list($usec, $sec) = explode(" ", microtime());
+	return ((float)$usec + (float)$sec);
 }
 
 function isin($haystack, $needle)
@@ -399,27 +399,43 @@ function get_group_status($grp_id)
 
 function get_short_monitor_name($mon_id)
 {
-	GLOBAL $TEST_TYPES;
-
 	$mon_query = db_query("
 		SELECT	test_id, test_params, test_type
 		FROM	monitors
 		WHERE	monitors.id = $mon_id");
 	$mon_row = db_fetch_array($mon_query);
 
-	switch($mon_row["test_type"])
+	return get_short_test_name($mon_row['test_type'], $mon_row['test_id'], $mon_row['test_params']);
+}
+
+function get_short_property_name($prop_id)
+{
+	$prop_query = db_query("
+		SELECT	test_id, test_params, test_type
+		FROM	dev_props
+		WHERE	dev_props.id = $prop_id");
+	$prop_row = db_fetch_array($prop_query);
+
+	return get_short_test_name($prop_row['test_type'], $prop_row['test_id'], $prop_row['test_params']);
+}
+
+function get_short_test_name($test_type, $test_id, $test_params)
+{
+	GLOBAL $TEST_TYPES;
+
+	switch($test_type)
 	{
 		case 1:
-			$test_query = "SELECT name FROM tests_script   WHERE id = " . $mon_row["test_id"];
+			$test_query = "SELECT name FROM tests_script   WHERE id = " . $test_id;
 			break;
 		case 2:
-			$test_query = "SELECT name FROM tests_snmp     WHERE id = " . $mon_row["test_id"];
+			$test_query = "SELECT name FROM tests_snmp     WHERE id = " . $test_id;
 			break;
 		case 3:
-			$test_query = "SELECT name FROM tests_sql      WHERE id = " . $mon_row["test_id"];
+			$test_query = "SELECT name FROM tests_sql      WHERE id = " . $test_id;
 			break;
 		case 4:
-			$test_query = "SELECT name FROM tests_internal WHERE id = " . $mon_row["test_id"];
+			$test_query = "SELECT name FROM tests_internal WHERE id = " . $test_id;
 			break;
 
 	} // end switch test type
@@ -428,13 +444,13 @@ function get_short_monitor_name($mon_id)
 
 	$res = $test_row["name"];
 
-	if ($mon_row["test_params"] != "")
+	if ($test_params != "")
 	{
-		$res .= " - " . $mon_row["test_params"];
+		$res .= " - " . $test_params;
 	}
 
 	return $res;
-} // end get_short_monitor_name()
+} // end get_short_test_name()
 
 
 function get_monitor_name($mon_id)
@@ -476,6 +492,8 @@ function get_device_name($dev_id)
 function get_sub_device_name($sub_dev_id)
 {
 	$dev_query = db_query("SELECT name FROM sub_devices WHERE id = $sub_dev_id");
+	if (db_num_rows($dev_query) == 0)
+		return "Not Set";
 	$row = db_fetch_array($dev_query);
 	return $row["name"];
 }
@@ -487,6 +505,8 @@ function get_dev_sub_device_name($sub_dev_id)
 		FROM sub_devices
 		LEFT JOIN devices   ON sub_devices.dev_id=devices.id
 		WHERE sub_devices.id = $sub_dev_id");
+	if (db_num_rows($dev_query) == 0)
+		return "Not Set";
 	$row = db_fetch_array($dev_query);
 	return $row["dev_name"] . " - " . $row["sub_name"];
 }
@@ -1046,6 +1066,9 @@ function delete_device($device_id, $group_id = false)
 		// remove the disk cache for the device
 		db_update("DELETE FROM snmp_disk_cache WHERE dev_id = '$device_id'");
 
+		// remove the device properties
+		db_update("DELETE FROM dev_prop_vals WHERE dev_id = '$device_id'");
+
 		// remove associated graphs
 		db_update("DELETE FROM view WHERE object_type='device' AND object_id = '$device_id'");
 
@@ -1411,4 +1434,4 @@ function PrereqsMet()
 	
 	return $errors;
 } // end PrereqsMet();
-?>
\ No newline at end of file
+?>
