@@ -23,7 +23,9 @@ $GLOBALS["netmrg"]["verhist"] = array(
 	"0.18" => 10,
 	"0.18.1" => 11,
 	"0.18.2" => 12,
-	"0.19" => 13
+	"0.19" => 13,
+	"0.19.1" => 14,
+	"0.20" => 15,
 ); // end verhist
 
 
@@ -40,7 +42,8 @@ $MENU = array(
 	),
 	"Admin" => array(
 		array("name" => "Devices", "link" => "grpdev_list.php", "descr" => "", "authLevelRequired" => 1),
-//		array("name" => "Device Types", "link" => "dev_types.php", "descr" => "", "authLevelRequired" => 2),
+		array("name" => "Device Types", "link" => "dev_types.php", "descr" => "", "authLevelRequired" => 2),
+		array("name" => "Device Properties", "link" => "dev_props.php", "descr" => "", "authLevelRequired" => 2, "display" => false),
 		array("name" => "Notifications", "link" => "notifications.php", "descr" => "", "authLevelRequired" => 1),
 		array("name" => "Custom Graphs", "link" => "graphs.php?type=custom", "descr" => "", "authLevelRequired" => 1),
 		array("name" => "Template Graphs", "link" => "graphs.php?type=template", "descr" => "", "authLevelRequired" => 1),
@@ -120,6 +123,11 @@ $RRDTOOL_ITEM_TYPES = array(
 	5 => "STACK"
 ); // end RRDTOOL_ITEM_TYPES
 
+$RRDTOOL_CFS = array(
+	1 => "AVERAGE",
+	2 => "MAX"
+); // end RRDTOOL_CFS
+
 $SPECIAL_MONITORS = array(
 	-1 => "-Fixed Value-",
 	-2 => "-Sum of all graph items-"
@@ -141,7 +149,7 @@ $PERMIT_TYPES = array(
 
 $SUB_DEVICE_TYPES = array(
 	1 => "Group",
-	2 => "Interface",
+	2 => "Network Interface",
 	3 => "Disk"
 ); // end SUB_DEVICE_TYPES
 
@@ -263,7 +271,8 @@ $SEARCH_ITEMS = array(
 	'device' => array(
 		'name' => "Device",
 		'sql' => array("SELECT id, name FROM devices 
-			WHERE name LIKE '%|ARG|%' OR ip LIKE '%|ARG|%'")
+			WHERE name LIKE '%|ARG|%' OR ip LIKE '%|ARG|%'",
+			"SELECT dev_id AS id, name FROM dev_prop_vals val LEFT JOIN devices dev ON val.dev_id=dev.id WHERE value LIKE '%|ARG|%'")
 		),
 	'subdevice' => array(
 		'name' => "Sub Device",
@@ -282,7 +291,8 @@ $TIMEFRAME_DAILY = array(
 	'end_time'   => "-360",
 	'break_time' => (time() - (date("s") + date("i") * 60 + date("H") * 3600)),
 	'sum_label'  => "24 Hour",
-	'sum_time'   => "86400"
+	'sum_time'   => "86400",
+	'show_max'   => false
 ); // end TIMEFRAME_DAILY
 
 $TIMEFRAME_WEEKLY = array(
@@ -291,7 +301,8 @@ $TIMEFRAME_WEEKLY = array(
 	'end_time'   => "-360",
 	'break_time' => (time() - (date("s") + date("i") * 60 + date("H") * 3600 + date("w") * 86400)),
 	'sum_label'  => "7 Day",
-	'sum_time'   => "604800"
+	'sum_time'   => "604800",
+	'show_max'   => true
 ); // end TIMEFRAME_WEEKLY
 
 $TIMEFRAME_MONTHLY = array(
@@ -300,7 +311,8 @@ $TIMEFRAME_MONTHLY = array(
 	'end_time'   => "-360",
 	'break_time' => (time() - (date("s") + date("i") * 60 + date("H") * 3600 + date("d") * 86400)),
 	'sum_label'  => "4 Week",
-	'sum_time'   => "2419200"
+	'sum_time'   => "2419200",
+	'show_max'   => true
 ); // end TIMEFRAME_MONTHLY
 
 $TIMEFRAME_YEARLY = array(
@@ -309,7 +321,8 @@ $TIMEFRAME_YEARLY = array(
 	'end_time'   => "-360",
 	'break_time' => (time() - (date("s") + date("i") * 60 + date("H") * 3600 + date("z") * 86400)),
 	'sum_label'  => "1 Year",
-	'sum_time'   => "31536000"
+	'sum_time'   => "31536000",
+	'show_max'   => true
 ); // end TIMEFRAME_YEARLY
 
 $TIMEFRAMES = array( $TIMEFRAME_DAILY, $TIMEFRAME_WEEKLY, $TIMEFRAME_MONTHLY, $TIMEFRAME_YEARLY );
@@ -399,6 +412,9 @@ function get_image_by_name($img_name)
 		case "recachedisk" :
 			$image = "{$GLOBALS['netmrg']['imagedir']}/{$GLOBALS['netmrg']['imagespec']['recachedisk']}";
 			break;
+		case "recacheproperties" :
+			$image = "{$GLOBALS['netmrg']['imagedir']}/{$GLOBALS['netmrg']['imagespec']['recacheproperties']}";
+			break;
 		case "viewdisk" :
 			$image = "{$GLOBALS['netmrg']['imagedir']}/{$GLOBALS['netmrg']['imagespec']['viewdisk']}";
 			break;
