@@ -72,24 +72,24 @@ function doedit()
 		if (!isset($_REQUEST["disabled"])) { $_REQUEST["disabled"] = 0; }
 		if (!isset($_REQUEST["snmp_version"])) { $_REQUEST["snmp_version"] = 0; }
 		if (!isset($_REQUEST["no_snmp_uptime_check"])) { $_REQUEST["no_snmp_uptime_check"] = 0; }
+		if (!isset($_REQUEST["unknowns_on_snmp_restart"])) { $_REQUEST["unknowns_on_snmp_restart"] = 0; }
 
 		if ($_REQUEST["dev_id"] == 0)
 		{
 			$db_cmd = "INSERT INTO";
 			$db_end = "";
 			$just_now_disabled = false;
+			$dev_type_changed = false;
 		}
 		else
 		{
 			$db_cmd = "UPDATE";
 			$db_end = "WHERE id={$_REQUEST['dev_id']}";
-			if ($_REQUEST['disabled'] == 1)
-			{
-				$q = db_query("SELECT disabled FROM devices WHERE id={$_REQUEST['dev_id']}");
-				$r = db_fetch_array($q);
-				$just_now_disabled = ($r['disable'] == 0);
-			}
-			else $just_now_disabled = false;
+			$q = db_query("SELECT disabled, dev_type FROM devices WHERE id={$_REQUEST['dev_id']}");
+			$r = db_fetch_array($q);
+			$just_now_disabled = (($r['disable'] == 0) && ($_REQUEST['disabled'] == 1));
+			$dev_type_changed = ($r['dev_type'] != $_REQUEST['dev_type']);
+			
 		} // end if dev_id = 0 or not
 
 		db_update("$db_cmd devices SET
@@ -103,7 +103,8 @@ function doedit()
 			snmp_port='{$_REQUEST['snmp_port']}',
 			snmp_timeout='{$_REQUEST['snmp_timeout']}',
 			snmp_retries='{$_REQUEST['snmp_retries']}',
-			no_snmp_uptime_check='{$_REQUEST['no_snmp_uptime_check']}' 
+			no_snmp_uptime_check='{$_REQUEST['no_snmp_uptime_check']}',
+			unknowns_on_snmp_restart='{$_REQUEST['unknowns_on_snmp_restart']}' 
 			$db_end");
 
 		if ($_REQUEST["dev_id"] == 0)
@@ -116,16 +117,34 @@ function doedit()
 			db_update("UPDATE devices SET status=0 WHERE id = {$_REQUEST['dev_id']}");
 			db_update("UPDATE sub_devices SET status=0 WHERE dev_id = {$_REQUEST['dev_id']}");
 			$q = db_query("SELECT id FROM sub_devices WHERE dev_id = {$_REQUEST['dev_id']}");
-			while ($r = db_fetch_array($q))
+			while ($r2 = db_fetch_array($q))
 			{
-				db_update("UPDATE monitors SET status=0 WHERE sub_dev_id = {$r['id']}");
-				$q1 = db_query("SELECT id FROM monitors WHERE sub_dev_id = {$r['id']}");
+				db_update("UPDATE monitors SET status=0 WHERE sub_dev_id = {$r2['id']}");
+				$q1 = db_query("SELECT id FROM monitors WHERE sub_dev_id = {$r2['id']}");
 				while ($r1 = db_fetch_array($q1))
 				{
 					db_update("UPDATE events SET last_status=0 WHERE mon_id = {$r1['id']}");
 				}
 			}
 		}
+
+		if ($dev_type_changed)
+		{
+			// the device type changed, so we need to migrate and/or clean up device properties
+			
+			$old_props_query = db_query("SELECT * FROM dev_props LEFT JOIN dev_prop_vals ON dev_props.id=dev_prop_vals.prop_id WHERE dev_type_id = {$r['dev_type']} AND dev_id = {$_REQUEST['dev_id']}");
+			while ($old_prop_row = db_fetch_array($old_props_query))
+			{
+				$new_props_query = db_query("SELECT * FROM dev_props WHERE dev_type_id = {$_REQUEST['dev_type']} AND name = '{$old_prop_row['name']}'");
+				if ($new_prop_row = db_fetch_array($new_props_query))
+				{
+					db_update("INSERT INTO dev_prop_vals SET dev_id={$_REQUEST['dev_id']}, prop_id={$new_prop_row['id']}, value='{$old_prop_row['value']}'");
+				}
+				
+				db_update("DELETE FROM dev_prop_vals WHERE dev_id={$_REQUEST['dev_id']} AND prop_id={$old_prop_row['prop_id']}");
+			}
+		}
+
 	} // done editing
 
 	header("Location: grpdev_list.php?parent_id={$_REQUEST['grp_id']}&tripid={$_REQUEST['tripid']}");
@@ -210,6 +229,7 @@ function displayedit()
 		$dev_row["snmp_timeout"] = 1000000;
 		$dev_row["snmp_retries"] = 3;
 		$dev_row["no_snmp_uptime_check"] = 0;
+		$dev_row["unknowns_on_snmp_restart"] = 1;
 	}
 
 	make_edit_table("Edit Device");
@@ -224,6 +244,7 @@ function displayedit()
 	make_edit_select_from_array("Recaching Method:", "snmp_recache_method", $GLOBALS["RECACHE_METHODS"], $dev_row["snmp_recache_method"]);
 	make_edit_group("Advanaced SNMP Options");
 	make_edit_checkbox("Disable SNMP Uptime Check", "no_snmp_uptime_check", $dev_row["no_snmp_uptime_check"] == 1);
+	make_edit_checkbox("Unknowns on SNMP Restart", "unknowns_on_snmp_restart", $dev_row["unknowns_on_snmp_restart"] == 1);
 	make_edit_text("SNMP UDP Port", "snmp_port", 5, 5, $dev_row["snmp_port"]);
 	make_edit_text("SNMP Timeout (microseconds):", "snmp_timeout", 10, 20, $dev_row["snmp_timeout"]);
 	make_edit_text("SNMP Retries:", "snmp_retries", 3, 10, $dev_row["snmp_retries"]);
