@@ -19,6 +19,7 @@ if (isset($_REQUEST['type']) && isset($_REQUEST['dev_id']))
 	{
 		case "interface":	do_interface_recache($_REQUEST['dev_id']); 	break;
 		case "disk":		do_disk_recache($_REQUEST['dev_id']); 		break;
+		case "properties":	do_properties_recache($_REQUEST['dev_id']); break;
 	}
 }
 
@@ -34,4 +35,11 @@ function do_disk_recache($dev_id)
 	header("Location: snmp_cache_view.php?action=view&type=disk&dev_id=$dev_id&tripid={$_REQUEST['tripid']}");
 }
 
+function do_properties_recache($dev_id)
+{
+	system($GLOBALS['netmrg']['binary'] . " -qP $dev_id");
+	header("Location: grpdev_list.php?parent_id={$_REQUEST['parent_id']}&tripid={$_REQUEST['tripid']}");
+}
+
+
 ?>
