@@ -213,7 +213,27 @@ $dbupdates = array(
 		array(
 			"name" => "Graph Max NULL Fix",
 			"query" => "UPDATE graphs SET max=NULL WHERE max=0")
-	) // end 0.19cvs
+	), // end 0.19
+
+	"0.19.1" => array(), // end 0.19
+
+	"0.20" => array(
+		array(
+			"name" => "Device Properties Table",
+			"query" => "CREATE TABLE `dev_props` (`id` INT NOT NULL AUTO_INCREMENT, `dev_type_id` INT NOT NULL, `name` VARCHAR( 200 ) NOT NULL, `test_type` TINYINT NOT NULL, `test_id` INT NOT NULL, `test_params` VARCHAR( 150 ) NOT NULL, PRIMARY KEY ( `id` )) TYPE = MYISAM ;"),
+		array(
+			"name" => "Device Properties Values Table",
+			"query" => "CREATE TABLE `dev_prop_vals` ( `dev_id` INT NOT NULL, `prop_id` INT NOT NULL, `value` VARCHAR( 250 ) NOT NULL, PRIMARY KEY ( `dev_id` , `prop_id` )) "),
+		array(
+			"name" => "SNMP Interface Cache New Fields",
+			"query" => "ALTER TABLE `snmp_interface_cache` ADD `nexthop` VARCHAR( 20 ) , ADD `vlan` VARCHAR( 20 ) , ADD `mode` TINYINT"),
+		array(
+			"name" => "Graph Item Consolidation Function Field",
+			"query" => "ALTER TABLE `graph_ds` ADD `cf` TINYINT NOT NULL DEFAULT '1'"),
+		array(
+			"name" => "Device Unknowns on SNMP Restart Field",
+			"query" => "ALTER TABLE `devices` ADD `unknowns_on_snmp_restart` TINYINT NOT NULL DEFAULT '1'")
+	), // end 0.20
 	
 ); // end $dbupdates;
 
